==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/it-IT/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessorio restituito',
    'Accessory_Checkout_Notification' => 'Accessorio assegnato',
    'Asset_Checkin_Notification' => 'Bene restituito',
    'Asset_Checkout_Notification' => 'Bene assegnato',
    'Confirm_Accessory_Checkin' => 'Conferma restituzione accessorio',
    'Confirm_Asset_Checkin' => 'Conferma restituzione del bene',
    'Confirm_accessory_delivery' => 'Conferma consegna accessorio',
    'Confirm_asset_delivery' => 'Conferma consegna del Bene',
    'Confirm_consumable_delivery' => 'Conferma consegna del consumabile',
    'Confirm_license_delivery' => 'Conferma assegnazione licenza',
    'Consumable_checkout_notification' => 'Consumabile assegnato',
    'Days' => 'Giorni',
    'Expected_Checkin_Date' => 'Un bene assegnato a te deve essere restituito il :date',
    'Expected_Checkin_Notification' => 'Promemoria: scadenza restituzione :name in avvicinamento',
    'Expected_Checkin_Report' => 'Report Beni in attesa di restituzione',
    'Expiring_Assets_Report' => 'Report Beni in scadenza.',
    'Expiring_Licenses_Report' => 'Report Licenze in scadenza.',
    'Item_Request_Canceled' => 'Richiesta dell\'articolo annullata',
    'Item_Requested' => 'Articolo richiesto',
    'License_Checkin_Notification' => 'Licenza restituita',
    'License_Checkout_Notification' => 'Licenza assegnata',
    'Low_Inventory_Report' => 'Rapporto di inventario basso',
    'a_user_canceled' => 'Un utente ha annullato una richiesta di articolo tramite sito web',
    'a_user_requested' => 'Un utente ha richiesto un elemento tramite il sito web',
    'acceptance_asset_accepted' => 'Un utente ha accettato un elemento',
    'acceptance_asset_declined' => 'Un utente ha rifiutato un elemento',
    'accessory_name' => 'Nome Accessorio',
    'additional_notes' => 'Note aggiuntive',
    'admin_has_created' => 'Un amministratore ha creato un account per te sul sito :web.',
    'asset' => 'Bene',
    'asset_name' => 'Nome Bene',
    'asset_requested' => 'Bene richiesto',
    'asset_tag' => 'Etichetta Bene',
    'assets_warrantee_alert' => 'C\'è :count bene con garanzia in scadenza nei prossimi :threshold giorni.|Ci sono :count beni con garanzia in scadenza nei prossimi :threshold giorni.',
    'assigned_to' => 'Assegnato a',
    'best_regards' => 'Cordiali saluti,',
    'canceled' => 'Annullato',
    'checkin_date' => 'Data Restituzione',
    'checkout_date' => 'Data di Assegnazione',
    'checkedout_from' => 'Assegnato a',
    'checkedin_from'  => 'Restituito da',
    'checked_into' => 'Assegnato nel',
    'click_on_the_link_accessory' => 'Fare clic sul collegamento in basso per confermare di aver ricevuto l\'accessorio.',
    'click_on_the_link_asset' => 'Per favore clicca sul link in basso per confermare di aver ricevuto il Bene.',
    'click_to_confirm' => 'Per favore, clicca sul seguente link per confermare il tuo account su :web :',
    'current_QTY' => 'Quantità attuale',
    'days' => 'Giorni',
    'expecting_checkin_date' => 'Data Restituzione Prevista',
    'expires' => 'Scade',
    'hello' => 'Salve',
    'hi' => 'Ciao',
    'i_have_read' => 'Ho letto e accetto i termini di utilizzo e ho ricevuto questo elemento.',
    'inventory_report' => 'Rapporto Inventario',
    'item' => 'Articolo',
    'item_checked_reminder' => 'Promemoria: attualmente hai :count elementi assegnati che non hai né accettato né rifiutato. Clicca sul link qui sotto per confermare la tua decisione.',
    'license_expiring_alert' => 'Tra :threshold giorni sta per scadere :count licenza. |Tra :threshold giorni stanno per scadere :count licenze.',
    'link_to_update_password' => 'Clicca sul seguente collegamento per aggiornare la tua password per :web :',
    'login' => 'Accesso:',
    'login_first_admin' => 'Accedi alla nuova installazione di Snipe-IT utilizzando le seguenti credenziali:',
    'low_inventory_alert' => 'C\'è :count elemento che è al di sotto del livello di scorta minima o lo sarà a breve. |Ci sono :count elementi che sono al di sotto del livello di scorta minima o lo saranno a breve.',
    'min_QTY' => 'Quantità minima',
    'name' => 'Nome',
    'new_item_checked' => 'Ti è stato assegnato un nuovo Bene, di seguito i dettagli.',
    'notes' => 'Note',
    'password' => 'Password',
    'password_reset' => 'Reimposta la password',
    'read_the_terms' => 'Leggi i termini di utilizzo qui sotto.',
    'read_the_terms_and_click' => 'Leggi qui sotto i termini di utilizzo e fai clic sul link in basso per confermare di averli letti ed accettati e di aver quindi ricevuto il bene.',
    'requested' => 'Richiesto',
    'reset_link' => 'Il tuo link per reimpostare la password',
    'reset_password' => 'Clicca qui per reimpostare la tua password:',
    'rights_reserved' => 'Tutti i diritti riservati.',
    'serial' => 'Seriale',
    'snipe_webhook_test' => 'Test Integrazione Snipe-IT',
    'snipe_webhook_summary' => 'Riassunto Test Integrazione Snipe-IT',
    'supplier' => 'Fornitore',
    'tag' => 'Etichetta',
    'test_email' => 'Email di prova da Snipe-IT',
    'test_mail_text' => 'Questo è un test di Snipe-IT Asset Management System. Se hai ricevuto questa mail, la posta funziona :)',
    'the_following_item' => 'Il seguente articolo è stato restituito: ',
    'to_reset' => 'Per reimpostare la tua password di :web, compila questo modulo:',
    'type' => 'Tipo',
    'upcoming-audits' => 'C\'è :count Bene da inventariare entro :threshold giorni.|Ci sono :count beni da inventariare entro :threshold giorni.',
    'user' => 'Utente',
    'username' => 'Nome utente',
    'unaccepted_asset_reminder' => 'Hai dei beni non accettati.',
    'welcome' => 'Benvenuto :name',
    'welcome_to' => 'Benvenuti in :web!',
    'your_assets' => 'Visualizza i tuoi Beni',
    'your_credentials' => 'Le tue credenziali Snipe-IT',
    'mail_sent' => 'Email inviata correttamente!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/it-IT/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessorio restituito',
    'Accessory_Checkout_Notification' => 'Accessorio assegnato',
    'Asset_Checkin_Notification' => 'Bene restituito',
    'Asset_Checkout_Notification' => 'Bene assegnato',
    'Confirm_Accessory_Checkin' => 'Conferma restituzione accessorio',
    'Confirm_Asset_Checkin' => 'Conferma restituzione del bene',
    'Confirm_accessory_delivery' => 'Conferma consegna accessorio',
    'Confirm_asset_delivery' => 'Conferma consegna del Bene',
    'Confirm_consumable_delivery' => 'Conferma consegna del consumabile',
    'Confirm_license_delivery' => 'Conferma assegnazione licenza',
    'Consumable_checkout_notification' => 'Consumabile assegnato',
    'Days' => 'Giorni',
    'Expected_Checkin_Date' => 'Un bene assegnato a te deve essere restituito il :date',
    'Expected_Checkin_Notification' => 'Promemoria: scadenza restituzione :name in avvicinamento',
    'Expected_Checkin_Report' => 'Report Beni in attesa di restituzione',
    'Expiring_Assets_Report' => 'Report Beni in scadenza.',
    'Expiring_Licenses_Report' => 'Report Licenze in scadenza.',
    'Item_Request_Canceled' => 'Richiesta dell\'articolo annullata',
    'Item_Requested' => 'Articolo richiesto',
    'License_Checkin_Notification' => 'Licenza restituita',
    'License_Checkout_Notification' => 'Licenza assegnata',
    'license_for'   => 'Licenza per',
    'Low_Inventory_Report' => 'Rapporto di inventario basso',
    'a_user_canceled' => 'Un utente ha annullato una richiesta di articolo tramite sito web',
    'a_user_requested' => 'Un utente ha richiesto un elemento tramite il sito web',
    'acceptance_asset_accepted' => 'Un utente ha accettato un elemento',
    'acceptance_asset_declined' => 'Un utente ha rifiutato un elemento',
    'accessory_name' => 'Nome Accessorio',
    'additional_notes' => 'Note aggiuntive',
    'admin_has_created' => 'Un amministratore ha creato un account per te sul sito :web.',
    'asset' => 'Bene',
    'asset_name' => 'Nome Bene',
    'asset_requested' => 'Bene richiesto',
    'asset_tag' => 'Etichetta Bene',
    'assets_warrantee_alert' => 'C\'è :count bene con garanzia in scadenza nei prossimi :threshold giorni.|Ci sono :count beni con garanzia in scadenza nei prossimi :threshold giorni.',
    'assigned_to' => 'Assegnato a',
    'best_regards' => 'Cordiali saluti,',
    'canceled' => 'Annullato',
    'checkin_date' => 'Data Restituzione',
    'checkout_date' => 'Data di Assegnazione',
    'checkedout_from' => 'Assegnato a',
    'checkedin_from'  => 'Restituito da',
    'checked_into' => 'Assegnato nel',
    'click_on_the_link_accessory' => 'Fare clic sul collegamento in basso per confermare di aver ricevuto l\'accessorio.',
    'click_on_the_link_asset' => 'Per favore clicca sul link in basso per confermare di aver ricevuto il Bene.',
    'click_to_confirm' => 'Per favore, clicca sul seguente link per confermare il tuo account su :web :',
    'current_QTY' => 'Quantità attuale',
    'days' => 'Giorni',
    'expecting_checkin_date' => 'Data Restituzione Prevista',
    'expires' => 'Scade',
    'hello' => 'Salve',
    'hi' => 'Ciao',
    'i_have_read' => 'Ho letto e accetto i termini di utilizzo e ho ricevuto questo elemento.',
    'inventory_report' => 'Rapporto Inventario',
    'item' => 'Articolo',
    'item_checked_reminder' => 'Promemoria: attualmente hai :count elementi assegnati che non hai né accettato né rifiutato. Clicca sul link qui sotto per confermare la tua decisione.',
    'license_expiring_alert' => 'Tra :threshold giorni sta per scadere :count licenza. |Tra :threshold giorni stanno per scadere :count licenze.',
    'link_to_update_password' => 'Clicca sul seguente collegamento per aggiornare la tua password per :web :',
    'login' => 'Accedi',
    'login_first_admin' => 'Accedi alla nuova installazione di Snipe-IT utilizzando le seguenti credenziali:',
    'low_inventory_alert' => 'C\'è :count elemento che è al di sotto del livello di scorta minima o lo sarà a breve. |Ci sono :count elementi che sono al di sotto del livello di scorta minima o lo saranno a breve.',
    'min_QTY' => 'Quantità minima',
    'name' => 'Nome',
    'new_item_checked' => 'Ti è stato assegnato un nuovo Bene, di seguito i dettagli.',
    'notes' => 'Note',
    'password' => 'Password',
    'password_reset' => 'Reimposta la password',
    'read_the_terms' => 'Leggi i termini di utilizzo qui sotto.',
    'read_the_terms_and_click' => 'Leggi qui sotto i termini di utilizzo e fai clic sul link in basso per confermare di averli letti ed accettati e di aver quindi ricevuto il bene.',
    'requested' => 'Richiesto',
    'reset_link' => 'Il tuo link per reimpostare la password',
    'reset_password' => 'Clicca qui per reimpostare la tua password:',
    'rights_reserved' => 'Tutti i diritti riservati.',
    'serial' => 'Seriale',
    'snipe_webhook_test' => 'Test Integrazione Snipe-IT',
    'snipe_webhook_summary' => 'Riassunto Test Integrazione Snipe-IT',
    'supplier' => 'Fornitore',
    'tag' => 'Etichetta',
    'test_email' => 'Email di prova da Snipe-IT',
    'test_mail_text' => 'Questo è un test di Snipe-IT Asset Management System. Se hai ricevuto questa mail, la posta funziona :)',
    'the_following_item' => 'Il seguente articolo è stato restituito: ',
    'to_reset' => 'Per reimpostare la tua password di :web, compila questo modulo:',
    'type' => 'Tipo',
    'upcoming-audits' => 'C\'è :count Bene da inventariare entro :threshold giorni.|Ci sono :count beni da inventariare entro :threshold giorni.',
    'user' => 'Utente',
    'username' => 'Nome utente',
    'unaccepted_asset_reminder' => 'Hai dei beni non accettati.',
    'welcome' => 'Benvenuto :name',
    'welcome_to' => 'Benvenuti in :web!',
    'your_assets' => 'Visualizza i tuoi Beni',
    'your_credentials' => 'Le tue credenziali Snipe-IT',
    'mail_sent' => 'Email inviata correttamente!',
];
